@@ -3,15 +3,19 @@ package DataFlow::Proc::Null;
 use strict;
 use warnings;
 
-# ABSTRACT: A null node, will discard any input and return undef in the output
+# ABSTRACT: A 'null' processor, will discard any input and return undef in the output
 # ENCODING: utf8
 
-our $VERSION = '0.950000';    # VERSION
+our $VERSION = '1.110860';    # VERSION
 
 use Moose;
 extends 'DataFlow::Proc';
 
-has '+process_into' => ( 'default' => 0, );
+has '+process_into' => (
+    'default'  => 0,
+    'init_arg' => undef,
+);
+
 has '+p' => (
     'default' => sub {
         return sub { }
@@ -29,11 +33,11 @@ no Moose;
 
 =head1 NAME
 
-DataFlow::Proc::Null - A null node, will discard any input and return undef in the output
+DataFlow::Proc::Null - A 'null' processor, will discard any input and return undef in the output
 
 =head1 VERSION
 
-version 0.950000
+version 1.110860
 
 =head1 SYNOPSIS
 
@@ -46,8 +50,8 @@ version 0.950000
 
 =head1 DESCRIPTION
 
-This class represents a null node: it will return undef regardless of any input
-provided to it.
+This class represents a null processor: it will return C<undef> regardless of
+any input provided to it.
 
 =head1 METHODS
 
